@@ -1,5 +1,13 @@
-print.epMCA <-
-function (x,...) {
+#' Print Multiple Correspondence Analysis (MCA) results
+#' 
+#' 
+#' @usage \method{print}{epMCA}(x,\dots)
+#' @param x an list that contains items to make into the epMCA class.
+#' @param \dots inherited/passed arguments for S3 print method(s).
+#' @author Derek Beaton and Cherise Chin-Fatt
+#' @keywords print
+#' @export print.epMCA
+print.epMCA <- function (x,...) {
 
 #list(fi=fi,di=di,ci=ci,ri=ri,fj=fj,cj=cj,rj=rj,dj=dj,t=taus,M=M,W=W,pdq=pdqFIN)
 
@@ -28,7 +36,7 @@ function (x,...) {
   res[15,] <- c("$pdq.uncor","Uncorrected SVD data")  
   res[16,] <- c("$X","X matrix to decompose")    
   res[17,] <- c("$hellinger","a boolean. TRUE if Hellinger distance was used.")      
-  res[18,] <- c("$symmetric","a boolean. TRUE if symmetric scores used for biplot.")        
+  res[18,] <- c("$symmetric","a boolean. TRUE if symmetric scores used.")        
   
   print(res)
 
