@@ -1,5 +1,13 @@
-print.epSVD <-
-function (x,...) {
+#' Print results from the singular value decomposition (SVD) in ExPosition
+#' 
+#' 
+#' @usage \method{print}{epSVD}(x,\dots)
+#' @param x an list that contains items to make into the epSVD class.
+#' @param \dots inherited/passed arguments for S3 print method(s).
+#' @author Derek Beaton and Cherise Chin-Fatt
+#' @keywords print
+#' @export print.epSVD
+print.epSVD <- function (x,...) {
 
 #list(fi=fi,di=di,ci=ci,ri=ri,fj=fj,cj=cj,rj=rj,dj=dj,t=taus,M=M,W=W,pdq=pdqFIN)
 
